@@ -1,6 +1,6 @@
 # cube's specific schema
 from yams.buildobjs import EntityType, SubjectRelation, String, Datetime, Time
-from yams.constraints import BoundConstraint, Attribute
+from yams.constraints import BoundaryConstraint, Attribute
 from cubicweb.schema import WorkflowableEntityType
 
 _ = unicode
@@ -18,28 +18,21 @@ class Calendar(EntityType):
 class Calendaruse(EntityType):
     """see projman"""
     start = Datetime()
-    stop = Datetime(constraints=[BoundConstraint('>=', Attribute('start'))])
+    stop = Datetime(constraints=[BoundaryConstraint('>=', Attribute('start'))])
     use_calendar = SubjectRelation('Calendar', cardinality='1*')
 
 
 class Daytype(EntityType):
     """see projman"""
     title = String(required=True, maxsize=32, internationalizable=True)
-    work_during = SubjectRelation('Timespan', cardinality='**')
-
-
-class Timespan(EntityType):
-    """see projman"""
-    start = Time(required=True)
-    stop = Time(required=True,
-                constraints=[BoundConstraint('>=', Attribute('start'))])
-
+    type = String(vocabulary=(_('dt_working'), _('dt_nonworking'),
+                              _('dt_working_am'), _('dt_working_pm')))
 
 class Timeperiod(WorkflowableEntityType):
     """ """
     start = Datetime(required=True)
     stop = Datetime(required=True,
-                    constraints=[BoundConstraint('>=', Attribute('start'))],
+                    constraints=[BoundaryConstraint('>=', Attribute('start'))],
                     description=_('last day of the timeperiod'))
     day_type = SubjectRelation('Daytype', cardinality='1*')
 
