@@ -1,8 +1,8 @@
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web.facet import RelationFacet
 
 class TimeperiodCalendarFacet(RelationFacet):
     __regid__ = 'timeperiod-calendar-facet'
-    __select__ = RelationFacet.__select__ & implements('Timeperiod',)
+    __select__ = RelationFacet.__select__ & is_instance('Timeperiod',)
     rtype = 'periods'
     target_attr = 'title'
