@@ -1,14 +1,14 @@
 from logilab.mtconverter import xml_escape
 
 from cubicweb.view import EntityView
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web.views import baseviews
 
 # out of context  ####################################################################
 
 
 class RecurrentDayOutOfContext(baseviews.OutOfContextView):
-    __select__ = implements('Recurrentday')
+    __select__ = is_instance('Recurrentday')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row,col)
@@ -17,7 +17,7 @@ class RecurrentDayOutOfContext(baseviews.OutOfContextView):
         self.w(u'</a>')
 
 class TimePeriodOutOfContext(baseviews.OutOfContextView):
-    __select__ = implements('Timeperiod')
+    __select__ = is_instance('Timeperiod')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row,col)
